/*
The following global variables are set in the playup.html.erb page:
  var screen_type = 'iphone_android_hvga';
  var app_loaded_locally = false;
  var ua  = navigator.userAgent;
*/

//
// Functions
//
var twitter_hash_url = null; // this is here because it is hard coded into the HTNL somewhere
var page = {
  time_last_action : new Date().getTime(),
  sound_file : null,
  currently_open : 'home',
  previous_open : null,
  internet_access : true,
  app_type : null,
  update_dynamic_timer : 0,
  
  init : function()
  {
    // Click handeller for buttons on home screen
    $('#grid a, #fixture_content a, #other_content a').live('click', function(event)
    {
      var show = this.href.substr(this.href.lastIndexOf('/') + 1);
      event.preventDefault();
      page.previous_open = page.currently_open;
      page.open_it(show);
    });
    
    // Disable loading new pages in Android - prevents an Android bug - occasionally misses the click event handler when clicking on a link.
    if (app_loaded_locally)
    {
      var els = $("#grid a").get();
      for (var i in els) els[i].href = "#" + els[i].href;
    }
    
    $('#playup').click(function()
    {
      if (app_loaded_locally) // use phonegap to play the sound
      {
        if (page.sound_file) page.sound_file.stop();    
        page.play_sound('playapp/sounds/startup.mp3');
      }
    });

    // Play audio on click
    $('.audio_play_link').click(function(event)
    {
      if (app_loaded_locally) // use phonegap to play the sound
      {
        if (page.sound_file) page.sound_file.stop();
        if (page.team && this.getAttribute("class").match("league_audio") == null) {
          page.play_sound("teams/" + page.team + "/s3_files/" + this.href.substr(this.href.lastIndexOf('/') + 1));
        } else {
          page.play_sound("s3_files/" + this.href.substr(this.href.lastIndexOf('/') + 1));      
        }
                  
      }
      else // play sounds through flash
      {
        window.document.mp3_player.SetVariable("mp3_file", this.href);
      }
      event.preventDefault();
    });

    // Set up page layout for different devices
    if (page.app_type == 'ipad')
    {
      //setTimeout( function() {
        if (screenshot_size == '') $(".page").not("#home").css('webkitTransform', 'translateX(218px)');
        page.open_it('news');
      //}, 1500);
    }
    else if (page.app_type == 'ipod' || page.app_type == 'iphone')
    {
      $(".page").not("#home").css('webkitTransform', 'translateX(100%)').show();
      page.currently_open = "home";
    }
    else
    {
      page.currently_open = "home";
    }
  },

  on_dom_ready : function() 
  {
    if (!app_loaded_locally)
    {
      page.init();
      page.detect_size();
      page.update_dynamic();
      page.load_ad();
    } // else do this stuff on deviceready (below)
  
    // Resizes the screen so that the home screen is allways full height. 
    var default_header_height = (page.app_type == 'iphone' || page.app_type == 'ipod') ? 21 : 0;
    $('.wrapper').height($(window).height() - $('#header_hack').height() - default_header_height);
    $('#grid').height($(window).height() - default_header_height);
  
    if (screenshot_size != '')  $('.wrapper').css("overflow", "hidden"); // do this for screenshots
  },
  
  on_load : function() 
  {
    // This code auto scrolls safari to hide the address bar 
    if (!app_loaded_locally && ua.toLowerCase().match(/iphone|ipod/i))
    {
      setTimeout(function()
      {
        window.scrollTo(0, 1);
        $('.wrapper').height($(window).height() - $('#header_hack').height() + 60);
        $('#grid').height($(window).height() + 60);
      }, 10);
    }
  
    if (app_loaded_locally) 
    {
      if (typeof navigator.device == "undefined") document.addEventListener("deviceready", page.on_device_ready, false);
      else page.on_device_ready();
    }
  },  
  
  on_device_ready : function()
  {
    if (app_loaded_locally && get_android_version(ua) >= 2.2)
    {
      // We have to treat Android 2.2+ differently to previous versions. 
      // 2.2+ does not allow us to detect the screen resolutioin until on-device ready. 
      // So we will have to defer checking this and setting the style sheet until then.
      
      screen_type = get_screentype(ua);

      var node  = document.createElement('link');
      node.type   = 'text/css';
      node.rel  = 'stylesheet';
      node.href   = 'playapp/stylesheets/' + screen_type + '.css';
      document.getElementsByTagName("head")[0].appendChild(node);
      
      // We have to wait until the stylesheet is loaded before we can use it's values.
      var load_interval = setInterval(function()
      {
        if ($('#header_hack').height() > 0)
        {
          clearInterval(load_interval);
          $('.wrapper').height($(window).height() - $('#header_hack').height());
          $('#grid').height($(window).height());
          page.detect_size();
        }
      }, 50);
    }
    // This is here because the resizing takes a while on Android and we don't want to show it at different sizes. 
    // Show a loading screen instead. Cannot show loading image because we don't know the size of the screen yet.
    $('#home').css('visibility', 'visible'); 
    $('#loading').hide();
    
    // Check for internet access
    $('#dynamic_content').html("<em>" + LBL_INTERNET_ACCESS_CHECK + "</em>");
    setTimeout(function()
    {
      navigator.network.isReachable("www.playapp.co", test_reachable_callback);
      //navigator.network.isReachable("192.168.0.1", testReachable_callback, { isIpAddress: true});
    }, 500);
  
    // Random other things to do in startup
    document.addEventListener('touchmove', function(e){ e.preventDefault(); }); // prevents scrolling in the page (we use iScroll instead)
    page.play_sound('playapp/sounds/startup.mp3');
  
    // Bind Back button key handler when we are running on Android and Android only
    if (page.app_type == 'android') 
    {
      device.overrideBackButton();
      document.addEventListener("backKeyDown", function()
      {
        if (page.currently_open != "home") page.open_it('home', true);
      }, false);
    
      document.addEventListener("menuKeyDown", function()
      {
        page.open_it('home', true); 
      }, false);
    }

    // iOS specific 
    if (page.app_type == 'iphone' || page.app_type == 'ipad' || page.app_type == 'ipod') 
    {
      page.watch_for_shake(1.5);
      document.addEventListener("appActive", page.app_active, false); // This is called when the app resumes (from background in multi-taskeing)
    }
  },
  
  detect_size : function() // Detects the screen size and adjusts the images accordingly
  {
    // Replace images
    var els = $(".button_row img, #board img, #playup, #logo").get();
    for (var i in els)
    {
      var src = els[i].src;
      src = src.replace("iphone_android_hvga", screen_type);
      els[i].src = src;
    }
    
    // Replace header background-image
    var src = $("#home").css("background-image");
    if (src)
    {
      src = src.replace("iphone_android_hvga", screen_type);
      $("#home").css("background-image", src);
    }
  },
  
  app_active : function()
  {
    // reload all the previosuly loaded content after 5 minutes ... when the app has been resumed.
    if (page.time_last_action < new Date().getTime() - (5 * 60 * 1000)) 
    { 
      page.play_sound('playapp/sounds/startup.mp3'); // use phonegap to play the sound
      $('#news_wrapper, #fixture_wrapper, #ladder_wrapper, #twitter_wrapper, #twitter_account_wrapper, #twitter_players_wrapper, #twitter_hash_wrapper, #other_wrapper').removeClass('loaded').empty();
      
      if (page.app_type == 'ipad') page.open_it('news');
      else page.open_it('home');
    }
    
    page.update_dynamic();
    page.load_ad(); 
  },
  
  open_it : function(show, back) // Open pages
  {
    // Set last page action - used for working our whether to reload the app when it resumes from running in the background on iOS
    page.time_last_action = new Date().getTime();

    original_show = show;
    show = original_show.split("?")[0];
    // Don't do this when loaded on "individual" pages (e.g. /leagues/1/teams/1/links)
    if ($('#' + show).length == 0) return true;

    // Stop sound files from playing when you close a page
    if (page.currently_open != null && page.sound_file && app_loaded_locally && (page.app_type == 'iphone' || page.app_type == 'ipad' || page.app_type == 'ipod' || page.app_type == 'android')) // use phonegap to stop the sound
      page.sound_file.stop();
    
    // Different way to show/hide pages depending on device
    if (screenshot_size != '')
    {
      $('#' + show).show();
    }
    else if (page.app_type == 'ipad')
    {
      if (page.currently_open != show)
      {
        if (page.currently_open != 'home') {
          $('#' + page.currently_open).css('webkitTransform', 'rotateY(90deg)');
        }
        $('#' + show).css(
        {
          'display' : 'block',
          'opacity' : 0,
          'webkitTransform' : 'rotateY(90deg)'
        });
        setTimeout(function()
        {
          if (page.currently_open != 'home') {
            $('#' + page.currently_open).css('display', 'none');
          }
          $('#' + show).css(
          {
            'display' : 'block',
            'opacity' : 1,
            'webkitTransform' : 'rotateY(0deg)'
          });
        }, 400);
      }
    }
    else if (page.app_type == 'ipod' || page.app_type == 'iphone')
    {
      if (back) $('#' + page.currently_open).css('webkitTransform', 'translateX(100%)');
      else $('#' + page.currently_open).css('webkitTransform', 'translateX(-100%)');
      $('#' + show).css('webkitTransform', 'translateX(0%)');
    }
    else if (page.app_type == 'android')
    {
      $('#' + page.currently_open).hide();
      $('#' + show).show();
    }
    else
    {
      if (back)
      {
        $('#' + page.currently_open).hide("slide", { direction:"right"});
        $('#' + show).show("slide", { direction:"left"});
      }
      else
      {
        $('#' + page.currently_open).hide("slide", { direction:"left"});
        $('#' + show).show("slide", { direction:"right" });
      }
    }

    page.currently_open = show;

    // Specific actions to perform when different pages open
    if (show == 'home'&& page.app_type != 'ipad') page.update_dynamic();
    else if (show == 'links' && ua.toLowerCase().match(/iphone|ipad|ipod|android/i)) myScroll = new iScroll('links_content');
    else if (show == 'news' || show == 'fixture' || show == 'ladder' || show == 'twitter' || show == 'twitter_account' || show == 'twitter_players' || show == 'twitter_hash' || show == 'other' || show == 'score_card')
    {
      if (!$('#' + show + '_wrapper').hasClass('loaded'))
      {
        var load_url = original_show;

        if (show == 'twitter_hash' || show == 'twitter_account')
        {
          var url_bits = twitter_hash_url.split("/");
          load_url = url_bits[url_bits.length - 1];
        }
        $('#' + show + '_wrapper').removeClass('error').addClass('loading').html(LBL_LOADING).load(base_url + load_url + ' #' + show + '_content', function(response, status, xhr)
        {
          if (status == "error") $('#' + show + '_wrapper').removeClass('loading').addClass('error').html(LBL_JS_ERROR + ': ' + xhr.status +' ' + xhr.statusText);
          else if (response == '' && !page.internet_access) $('#' + show + '_wrapper').removeClass('loading').addClass('error').html(LBL_INTERNET_ERROR);
          else if (response == '') $('#' + show + '_wrapper').removeClass('loading').addClass('error').html(LBL_CONNECTION_ERROR);
          else
          {
            if (show == 'news' || show == 'fixture' || show == 'ladder' || show == 'twitter') $('#' + show + '_wrapper').removeClass('loading').addClass('loaded'); // means we will not reload this page
            else $('#' + show + '_wrapper').removeClass('loading');                                        
            
            if (ua.toLowerCase().match(/iphone|ipad|ipod|android/i)) myScroll = new iScroll(show + '_content');
            if (page.app_type == 'ipod' || page.app_type == 'iphone' || page.app_type == 'ipad') navigator.notification.vibrate(0);
          }
        });
      }
    }
    
    // Stop the default actions from occuring
    return false;
  },
  
  load_ad : function() // Loads the add on the home screen
  {
    if ($(window).width() >= 320) {
      $('#advertisement').load(base_url + 'advertisement' + '?screen_type=' + screen_type + '&app_loaded_locally=' + app_loaded_locally);
    } else {
      // do nothing
      $('#advertisement').html("&nbsp;");
    }
  },
  
  update_dynamic : function() // Updates the content in the bar under the header (e.g. live scores)
  {
    clearTimeout(page.update_dynamic_timer);
    $('#dynamic_content').load(base_url + 'scores');
    
    // If there is a live game going on, refresh the scores every 60 seconds
    if ($('table.live').length > 0) page.update_dynamic_timer = setTimeout(page.update_dynamic, SCORE_UPDATE_FREQUENCY_SECONDS * 1000);
  },
  
  watch_for_shake : function(threshold) // Easter egg. If the user shakes the device it will play a croud noise
  {
    var axl = new Accelerometer();
    axl.watchAcceleration(function (Accel)
    {
      if (true === Accel.is_updating) return;
      if (Accel.x >= threshold || Accel.x <= (0 - threshold)) page.play_sound('playapp/sounds/cheer.mp3');
    }, function(){}, {frequency : 750});  
  },
  
  play_sound : function (path)
  {
    path = page.app_type == 'android' ? '/android_asset/www/' + path : path; // http://groups.google.com/group/phonegap/browse_thread/thread/6e2d574d9256c389/57e527940f356ab9?#57e527940f356ab9
    page.sound_file = new Media(path);
    page.sound_file.play();
  },

  change_team : function() 
  {
    localStorage.removeItem("team");
    document.location = "../../index.html";
    return false;
  } 
};

//
// Callback function when we test to see if there is interent access on the app (has to be in a seperate function)
//
function test_reachable_callback(reachability) {
  page.init();
  if (reachability.remoteHostStatus == 0) {
    if (reachability.internetConnectionStatus == 0 && reachability.localWiFiConnectionStatus == 0)
      $('#dynamic_content').html('<em>' + LBL_INTERNET_ERROR + '</em>');
    else
      $('#dynamic_content').html('<em>' + LBL_CONNECTION_ERROR + '</em>');
    page.internet_access = false;
  } else {
    $('#dynamic_content').html('<em>' + LBL_LOADING + '</em>');
    page.load_ad();
    page.update_dynamic();
  }
}


//
// Work out whether the app has been loaded locally and if so, what type.
//
if (app_loaded_locally || screenshot_size != '') {
  if (screenshot_size != '')                    page.app_type = screenshot_size;
  else if (ua.toLowerCase().match(/iphone/i))   page.app_type = 'iphone';
  else if (ua.toLowerCase().match(/ipad/i))     page.app_type = 'ipad';
  else if (ua.toLowerCase().match(/ipod/i))     page.app_type = 'ipod';
  else if (ua.toLowerCase().match(/android/i))  page.app_type = 'android';
}

//
// Loading sequence
//
if (app_loaded_locally && (page.app_type != 'android' || get_android_version(ua) < 2.2)) page.detect_size();
$(document).ready(page.on_dom_ready); // This is called on DOM ready (i.e. before everything has loaded but the DOM is accessible).
$(window).bind("load", page.on_load); // This is called when all the elements in the browser/app are loaded (on load)
